@@ -320,11 +320,11 @@ def load_model(model_name, model_prefix, model_epoch, context_lookup_names, sequ
 
 
 def load_offer_metadata(offer_pool_path, s3_id_mapping_bucket, s3_id_mapping_prefix, s3_rest_tz_bucket,
-                        s3_rest_tz_prefix):
+                        s3_rest_tz_prefix, access_key, secret_key):
     # id_mapping
     keys = []
     id_mapping_dfs = []
-    s3 = boto3.client('s3')
+    s3 = boto3.client('s3', aws_access_key_id=access_key, aws_secret_access_key=secret_key)
     list_obj = s3.list_objects_v2(Bucket=s3_id_mapping_bucket, Prefix=s3_id_mapping_prefix)
     assert list_obj["KeyCount"] < 1000
     for content in list_obj["Contents"]:
@@ -346,7 +346,7 @@ def load_offer_metadata(offer_pool_path, s3_id_mapping_bucket, s3_id_mapping_pre
     # rest_tz
     keys = []
     rest_tz_dfs = []
-    s3 = boto3.client('s3')
+    s3 = boto3.client('s3', aws_access_key_id=access_key, aws_secret_access_key=secret_key)
     list_obj = s3.list_objects_v2(Bucket=s3_rest_tz_bucket, Prefix=s3_rest_tz_prefix)
     assert list_obj["KeyCount"] < 1000
     for content in list_obj["Contents"]:
